﻿using System;
using Infragistics;
using UIKit;
using CustomSparklineColumn_Xamarin;
using Foundation;
using System.Collections.Generic;

namespace SparklineInGrid
{
	public partial class ViewController : UIViewController
	{
		#region member vars
		IGGridView _grid;
		// the datasource property on the iggridview holds a weak reference to this object, so we need
		// to make sure the view controller (or another persistant object) maintains the helper;
		IGGridViewDataSourceHelper _helper;
		#endregion 

		public ViewController (IntPtr handle) : base (handle)
		{
			
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			// Perform any additional setup after loading the view, typically from a nib.

			// adding a grid to the view and setting up properties on it
			_grid = new IGGridView ();
			_grid.Frame = new CoreGraphics.CGRect (0, 0, this.View.Bounds.Size.Width, this.View.Bounds.Size.Height);
			_grid.AutoresizingMask = UIViewAutoresizing.FlexibleHeight | UIViewAutoresizing.FlexibleWidth;
			this.View.Add (_grid);
			_grid.RowHeight = 150.0f;

			// setting up the DataSourceHelper
			_helper = new IGGridViewDataSourceHelper ();
			_helper.AutoGenerateColumns = false;

			// Adding columns to our grid, including our custom columns
			IGGridViewColumnDefinition nameColumn = new IGGridViewColumnDefinition ("teamName");
			_helper.ColumnDefinitions.Add (nameColumn);
			nameColumn.HeaderText = "Team Name";

			CurrentRecordColumnDefinition currentRecColumn = new CurrentRecordColumnDefinition ("currentRecord");
			currentRecColumn.HeaderText = "Overall Record";
			_helper.ColumnDefinitions.Add (currentRecColumn);

			IGSparklineColumnDefinition recordColumn = new IGSparklineColumnDefinition ("recordData");
			recordColumn.HeaderText = "Current Streak";
			_helper.ColumnDefinitions.Add (recordColumn);

			_helper.Data =  this.MakeData () ;
			_grid.DataSource = _helper;
		}

		public override void DidReceiveMemoryWarning ()
		{
			base.DidReceiveMemoryWarning ();
			// Release any cached data, images, etc that aren't in use.
		}
		NSObject[] MakeData()
		{
			Random ran = new Random ();
			List<TeamSeasonData> data = new List<TeamSeasonData> ();
			for (int i = 0; i < 40; i++) {
				TeamSeasonData t = new TeamSeasonData ();
				t.TeamName = "Team " + i.ToString ();
				List<NSNumber> gameData = new List<NSNumber> ();
				for (int j = 0; j <= 10; j++) {
					int winOrLoss = ran.Next () % 11;
					if (winOrLoss == 0) {
						gameData.Add (new NSNumber (0));
					} else if (winOrLoss % 2 == 0) {
						gameData.Add (new NSNumber (1)); // win
					} else {
						gameData.Add (new NSNumber (-1)); // loss
					}
				}
				t.RecordData = gameData.ToArray();
				data.Add (t);
			}
			return data.ToArray();
		}
	}
}

